Struct staging_xcm_executor::FeesMode
source · pub struct FeesMode {
pub jit_withdraw: bool,
}Expand description
A struct to specify how fees are being paid.
Fields
jit_withdraw: boolIf true, then the fee assets are taken directly from the origin’s on-chain account, otherwise the fee assets are taken from the holding register.
Defaults to false.